import requests
from cacheout import Cache
import time

class Client:

    def __init__(self, username, api_key, wanted_keys, is_production=False):
        '''
        :param username: user name for flight aware api
        :param api_key: api key for flight aware api
        :param wanted_keys: list of wanted keys to retrieve from the flight aware response payload
        '''

        self.FXML_URL = "https://flightxml.flightaware.com/json/FlightXML3/"
        self.authentication_info = (username, api_key)
        self.wanted_keys = wanted_keys
        self.is_production = is_production

        self.stubbed_find_flights_using_origin_destination_response = {'FindFlightResult': {'num_flights': 15, 'flights': [{'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560346519-airline-0332', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N359DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10320, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560526800, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:40AM', 'date': '06/14/2019', 'localtime': 1560512400}, 'estimated_departure_time': {'epoch': 1560527520, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:52AM', 'date': '06/14/2019', 'localtime': 1560513120}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560537120, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:32PM', 'date': '06/14/2019', 'localtime': 1560522720}, 'estimated_arrival_time': {'epoch': 1560537899, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:44PM', 'date': '06/14/2019', 'localtime': 1560523499}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 779, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560338700-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560348180-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9780, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560520980, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:03AM', 'date': '06/14/2019', 'localtime': 1560506580}, 'estimated_departure_time': {'epoch': 1560522420, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:27AM', 'date': '06/14/2019', 'localtime': 1560508020}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560530760, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:46PM', 'date': '06/14/2019', 'localtime': 1560516360}, 'estimated_arrival_time': {'epoch': 1560532259, 'tz': 'EDT', 'dow': 'Friday', 'time': '01:10PM', 'date': '06/14/2019', 'localtime': 1560517859}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560333660-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560341100-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N349DX', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513900, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:05AM', 'date': '06/14/2019', 'localtime': 1560499500}, 'estimated_departure_time': {'epoch': 1560514500, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:15AM', 'date': '06/14/2019', 'localtime': 1560500100}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560523620, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:47AM', 'date': '06/14/2019', 'localtime': 1560509220}, 'estimated_arrival_time': {'epoch': 1560524220, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:57AM', 'date': '06/14/2019', 'localtime': 1560509820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560260106-airline-0483', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560340800-schedule-0003', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N970JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513600, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:00AM', 'date': '06/14/2019', 'localtime': 1560499200}, 'estimated_departure_time': {'epoch': 1560514800, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:20AM', 'date': '06/14/2019', 'localtime': 1560500400}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560523320, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:42AM', 'date': '06/14/2019', 'localtime': 1560508920}, 'estimated_arrival_time': {'epoch': 1560524550, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:02AM', 'date': '06/14/2019', 'localtime': 1560510150}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU2504-1560320760-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU601', 'faFlightID': 'JBU601-1560331800-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '601', 'tailnumber': 'N965JT', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560504600, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:30AM', 'date': '06/14/2019', 'localtime': 1560490200}, 'estimated_departure_time': {'epoch': 1560505200, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:40AM', 'date': '06/14/2019', 'localtime': 1560490800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560514140, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:09AM', 'date': '06/14/2019', 'localtime': 1560499740}, 'estimated_arrival_time': {'epoch': 1560514740, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:19AM', 'date': '06/14/2019', 'localtime': 1560500340}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU36-1560260103-airline-0369', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL667', 'faFlightID': 'DAL667-1560260106-airline-0188', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '667', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10500, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'estimated_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'estimated_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2456-1560260106-airline-0264', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1201', 'faFlightID': 'JBU1201-1560260107-airline-0090', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1201', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560465600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:40PM', 'date': '06/13/2019', 'localtime': 1560451200}, 'estimated_departure_time': {'epoch': 1560466320, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:52PM', 'date': '06/13/2019', 'localtime': 1560451920}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560475140, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:19PM', 'date': '06/13/2019', 'localtime': 1560460740}, 'estimated_arrival_time': {'epoch': 1560475866, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:31PM', 'date': '06/13/2019', 'localtime': 1560461466}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1528-1560260103-airline-0426', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1401', 'faFlightID': 'JBU1401-1560260107-airline-0256', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1401', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12660, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560457800, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:30PM', 'date': '06/13/2019', 'localtime': 1560443400}, 'estimated_departure_time': {'epoch': 1560457200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:20PM', 'date': '06/13/2019', 'localtime': 1560442800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560470460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01PM', 'date': '06/13/2019', 'localtime': 1560456060}, 'estimated_arrival_time': {'epoch': 1560469860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:51PM', 'date': '06/13/2019', 'localtime': 1560455460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1202-1560260107-airline-0182', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL1656', 'faFlightID': 'DAL1656-1560260106-airline-0608', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1656', 'tailnumber': 'N304DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10920, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'estimated_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'estimated_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2938-1560265200-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU201', 'faFlightID': 'JBU201-1560260103-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N804JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10140, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 SPIKY AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560444360, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:46PM', 'date': '06/13/2019', 'localtime': 1560429960}, 'estimated_departure_time': {'epoch': 1560443760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:36PM', 'date': '06/13/2019', 'localtime': 1560429360}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560454500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:35PM', 'date': '06/13/2019', 'localtime': 1560440100}, 'estimated_arrival_time': {'epoch': 1560453900, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:25PM', 'date': '06/13/2019', 'localtime': 1560439500}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 780, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560258360-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560260106-airline-0115', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10440, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 472, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560440400, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:40AM', 'date': '06/13/2019', 'localtime': 1560426000}, 'estimated_departure_time': {'epoch': 1560440100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:35AM', 'date': '06/13/2019', 'localtime': 1560425700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560450840, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:34PM', 'date': '06/13/2019', 'localtime': 1560436440}, 'estimated_arrival_time': {'epoch': 1560450540, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:29PM', 'date': '06/13/2019', 'localtime': 1560436140}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560252300-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560261780-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N954JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560434580, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:03AM', 'date': '06/13/2019', 'localtime': 1560420180}, 'estimated_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'actual_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560444300, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:45PM', 'date': '06/13/2019', 'localtime': 1560429900}, 'estimated_arrival_time': {'epoch': 1560448080, 'tz': 'EDT', 'dow': 'Thursday', 'time': '01:48PM', 'date': '06/13/2019', 'localtime': 1560433680}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 420, 'status': 'En Route / Delayed', 'progress_percent': 21, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560247260-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU627', 'faFlightID': 'JBU627-1560254460-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '627', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12900, 'route': 'RBV J230 COPES J75 DHP ZQA RENAH Y397 SEKAR', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 2089, 'filed_departure_time': {'epoch': 1560427260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01AM', 'date': '06/13/2019', 'localtime': 1560412860}, 'estimated_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'actual_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'departure_delay': 6103, 'filed_arrival_time': {'epoch': 1560440160, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:36AM', 'date': '06/13/2019', 'localtime': 1560425760}, 'estimated_arrival_time': {'epoch': 1560444956, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:55PM', 'date': '06/13/2019', 'localtime': 1560430556}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 9360, 'status': 'En Route / Delayed', 'progress_percent': 60, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1760-1560173686-airline-0187', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560254400-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 452, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:00AM', 'date': '06/13/2019', 'localtime': 1560412800}, 'estimated_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'actual_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560437220, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:47AM', 'date': '06/13/2019', 'localtime': 1560422820}, 'estimated_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'actual_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'arrival_delay': -1080, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU162-1560173686-airline-0243', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560254700-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N376DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9360, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:05AM', 'date': '06/13/2019', 'localtime': 1560413100}, 'estimated_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'actual_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'departure_delay': 1840, 'filed_arrival_time': {'epoch': 1560436860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:41AM', 'date': '06/13/2019', 'localtime': 1560422460}, 'estimated_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'actual_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'arrival_delay': 2040, 'status': 'Arrived / Delayed', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560173691-airline-0611', 'adhoc': False}]}], 'next_offset': 15}}, {'num_flights': 15, 'flights': [{'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560346519-airline-0332', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N359DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10320, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560526800, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:40AM', 'date': '06/14/2019', 'localtime': 1560512400}, 'estimated_departure_time': {'epoch': 1560527520, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:52AM', 'date': '06/14/2019', 'localtime': 1560513120}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560537120, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:32PM', 'date': '06/14/2019', 'localtime': 1560522720}, 'estimated_arrival_time': {'epoch': 1560537899, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:44PM', 'date': '06/14/2019', 'localtime': 1560523499}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 779, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560338700-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560348180-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9780, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560520980, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:03AM', 'date': '06/14/2019', 'localtime': 1560506580}, 'estimated_departure_time': {'epoch': 1560522420, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:27AM', 'date': '06/14/2019', 'localtime': 1560508020}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560530760, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:46PM', 'date': '06/14/2019', 'localtime': 1560516360}, 'estimated_arrival_time': {'epoch': 1560532259, 'tz': 'EDT', 'dow': 'Friday', 'time': '01:10PM', 'date': '06/14/2019', 'localtime': 1560517859}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560333660-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560341100-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N349DX', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513900, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:05AM', 'date': '06/14/2019', 'localtime': 1560499500}, 'estimated_departure_time': {'epoch': 1560514500, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:15AM', 'date': '06/14/2019', 'localtime': 1560500100}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560523620, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:47AM', 'date': '06/14/2019', 'localtime': 1560509220}, 'estimated_arrival_time': {'epoch': 1560524220, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:57AM', 'date': '06/14/2019', 'localtime': 1560509820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560260106-airline-0483', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560340800-schedule-0003', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N970JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513600, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:00AM', 'date': '06/14/2019', 'localtime': 1560499200}, 'estimated_departure_time': {'epoch': 1560514800, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:20AM', 'date': '06/14/2019', 'localtime': 1560500400}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560523320, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:42AM', 'date': '06/14/2019', 'localtime': 1560508920}, 'estimated_arrival_time': {'epoch': 1560524550, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:02AM', 'date': '06/14/2019', 'localtime': 1560510150}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU2504-1560320760-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU601', 'faFlightID': 'JBU601-1560331800-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '601', 'tailnumber': 'N965JT', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560504600, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:30AM', 'date': '06/14/2019', 'localtime': 1560490200}, 'estimated_departure_time': {'epoch': 1560505200, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:40AM', 'date': '06/14/2019', 'localtime': 1560490800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560514140, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:09AM', 'date': '06/14/2019', 'localtime': 1560499740}, 'estimated_arrival_time': {'epoch': 1560514740, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:19AM', 'date': '06/14/2019', 'localtime': 1560500340}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU36-1560260103-airline-0369', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL667', 'faFlightID': 'DAL667-1560260106-airline-0188', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '667', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10500, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'estimated_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'estimated_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2456-1560260106-airline-0264', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1201', 'faFlightID': 'JBU1201-1560260107-airline-0090', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1201', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560465600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:40PM', 'date': '06/13/2019', 'localtime': 1560451200}, 'estimated_departure_time': {'epoch': 1560466320, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:52PM', 'date': '06/13/2019', 'localtime': 1560451920}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560475140, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:19PM', 'date': '06/13/2019', 'localtime': 1560460740}, 'estimated_arrival_time': {'epoch': 1560475866, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:31PM', 'date': '06/13/2019', 'localtime': 1560461466}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1528-1560260103-airline-0426', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1401', 'faFlightID': 'JBU1401-1560260107-airline-0256', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1401', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12660, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560457800, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:30PM', 'date': '06/13/2019', 'localtime': 1560443400}, 'estimated_departure_time': {'epoch': 1560457200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:20PM', 'date': '06/13/2019', 'localtime': 1560442800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560470460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01PM', 'date': '06/13/2019', 'localtime': 1560456060}, 'estimated_arrival_time': {'epoch': 1560469860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:51PM', 'date': '06/13/2019', 'localtime': 1560455460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1202-1560260107-airline-0182', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL1656', 'faFlightID': 'DAL1656-1560260106-airline-0608', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1656', 'tailnumber': 'N304DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10920, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'estimated_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'estimated_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2938-1560265200-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU201', 'faFlightID': 'JBU201-1560260103-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N804JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10140, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 SPIKY AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560444360, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:46PM', 'date': '06/13/2019', 'localtime': 1560429960}, 'estimated_departure_time': {'epoch': 1560443760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:36PM', 'date': '06/13/2019', 'localtime': 1560429360}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560454500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:35PM', 'date': '06/13/2019', 'localtime': 1560440100}, 'estimated_arrival_time': {'epoch': 1560453900, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:25PM', 'date': '06/13/2019', 'localtime': 1560439500}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 780, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560258360-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560260106-airline-0115', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10440, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 472, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560440400, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:40AM', 'date': '06/13/2019', 'localtime': 1560426000}, 'estimated_departure_time': {'epoch': 1560440100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:35AM', 'date': '06/13/2019', 'localtime': 1560425700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560450840, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:34PM', 'date': '06/13/2019', 'localtime': 1560436440}, 'estimated_arrival_time': {'epoch': 1560450540, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:29PM', 'date': '06/13/2019', 'localtime': 1560436140}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560252300-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560261780-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N954JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560434580, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:03AM', 'date': '06/13/2019', 'localtime': 1560420180}, 'estimated_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'actual_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560444300, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:45PM', 'date': '06/13/2019', 'localtime': 1560429900}, 'estimated_arrival_time': {'epoch': 1560448080, 'tz': 'EDT', 'dow': 'Thursday', 'time': '01:48PM', 'date': '06/13/2019', 'localtime': 1560433680}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 420, 'status': 'En Route / Delayed', 'progress_percent': 21, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560247260-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU627', 'faFlightID': 'JBU627-1560254460-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '627', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12900, 'route': 'RBV J230 COPES J75 DHP ZQA RENAH Y397 SEKAR', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 2089, 'filed_departure_time': {'epoch': 1560427260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01AM', 'date': '06/13/2019', 'localtime': 1560412860}, 'estimated_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'actual_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'departure_delay': 6103, 'filed_arrival_time': {'epoch': 1560440160, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:36AM', 'date': '06/13/2019', 'localtime': 1560425760}, 'estimated_arrival_time': {'epoch': 1560444956, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:55PM', 'date': '06/13/2019', 'localtime': 1560430556}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 9360, 'status': 'En Route / Delayed', 'progress_percent': 60, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1760-1560173686-airline-0187', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560254400-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 452, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:00AM', 'date': '06/13/2019', 'localtime': 1560412800}, 'estimated_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'actual_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560437220, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:47AM', 'date': '06/13/2019', 'localtime': 1560422820}, 'estimated_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'actual_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'arrival_delay': -1080, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU162-1560173686-airline-0243', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560254700-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N376DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9360, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:05AM', 'date': '06/13/2019', 'localtime': 1560413100}, 'estimated_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'actual_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'departure_delay': 1840, 'filed_arrival_time': {'epoch': 1560436860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:41AM', 'date': '06/13/2019', 'localtime': 1560422460}, 'estimated_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'actual_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'arrival_delay': 2040, 'status': 'Arrived / Delayed', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560173691-airline-0611', 'adhoc': False}]}], 'next_offset': 15}

        if (self.is_production):
            self.flight_aware_cache = Cache(maxsize=200, ttl=300, timer=time.time, default=None)

    def __make_request(self, payload):
        key = str(payload)
        response = self.flight_aware_cache.get(key)
        if (response == None):
            print("Cache Miss!")
            response = requests.get(self.FXML_URL + "FindFlight", params=payload, auth=self.authentication_info)
            self.flight_aware_cache.add(key, response)
        else:
            print("Cache Hit!")

        if response.status_code == 200:
            decodedResponse = response.json()
            print(decodedResponse)
            return decodedResponse
        else:
            print("Unable to retrieve flight aware data")
            return RuntimeError("Unable to retrieve flight aware data")

    # @DeprecationWarning
    # def find_flights_with_airline_info(self, airline_info):
    #     '''
    #     :param airline_info: 'DAL127'
    #     :return: list of flights that match the flight #
    #     '''
    #     if (self.is_production):
    #         payload = {'ident': airline_info}
    #         return self.__filter_completed_flights(self.__make_request(payload))
    #     else:
    #         return self.stubbed_find_flights_with_airline_info_response

    def find_flights_using_origin_destination(self, origin, destination):
        '''

        :param origin: Origin airport ID
        :param destination: Destination airport ID
        :return: list of matching flights on that route
        '''
        if (self.is_production):
            payload = {'origin': origin, 'destination': destination, 'type': 'nonstop'}
            return self.__make_request(payload)
        else:
            return self.stubbed_find_flights_with_flight_aware_identifier_info_response

    # @DeprecationWarning
    # def __filter_completed_flights(self, json_payload):
    #     scrubbed_payload = []
    #     try:
    #         for flight in json_payload:
    #             if flight['progress_percent'] < 100:
    #                 flight = self.__truncate_flight_data(flight)
    #                 scrubbed_payload.append(flight)
    #         return scrubbed_payload
    #     except RuntimeError:
    #         print("Unable to scrub flight aware data")
    #         return RuntimeError("Unable to scrub flight aware data")
    #
    # @DeprecationWarning
    # def __truncate_flight_data(self, flight):
    #     flight_data = {your_key: flight[your_key] for your_key in self.wanted_keys}
    #     return flight_data

